Index: chrome/browser/browser.h |
diff --git a/chrome/browser/browser.h b/chrome/browser/browser.h |
index 3ae61210ee553504888fc758ba37cdf5bb4c1661..3c2f973712c1389ceaf99dbc4afd14cb9b715a2f 100644 |
--- a/chrome/browser/browser.h |
+++ b/chrome/browser/browser.h |
@@ -162,8 +162,8 @@ class Browser : public TabStripModelDelegate, |
// Gets the FavIcon of the page in the selected tab. |
SkBitmap GetCurrentPageIcon() const; |
- // Gets the title of the page in the selected tab. |
- string16 GetCurrentPageTitle() const; |
+ // Gets the title of the window based on the selected tab's title. |
+ string16 GetWindowTitleForCurrentTab() const; |
// Prepares a title string for display (removes embedded newlines, etc). |
static void FormatTitleForDisplay(string16* title); |